@@ -1,6 +1,5 @@
 //! Rendering primitives, routines, and structures.
 
-mod config_ui;
 mod draw_config;
 mod drawables;
 mod geometries;
@@ -13,7 +12,8 @@ mod vertices;
 
 pub use self::{
     draw_config::DrawConfig,
-    renderer::{DrawError, InitError, Renderer},
+    renderer::{DrawError, Renderer, RendererInitError},
 };
 
-const DEPTH_FORMAT: wgpu::TextureFormat = wgpu::TextureFormat::Depth32Float;
+pub const DEPTH_FORMAT: wgpu::TextureFormat = wgpu::TextureFormat::Depth32Float;
+pub const SAMPLE_COUNT: u32 = 4;
