@@ -14,8 +14,20 @@
 
 #![warn(missing_docs)]
 
-pub mod camera;
-pub mod graphics;
-pub mod input;
-pub mod run;
-pub mod window;
+mod camera;
+mod graphics;
+mod gui;
+mod input;
+mod screen;
+mod status_report;
+mod viewer;
+
+pub use self::{
+    camera::Camera,
+    graphics::{DrawConfig, Renderer, RendererInitError},
+    gui::{Gui, GuiState},
+    input::{InputEvent, InputHandler},
+    screen::{NormalizedScreenPosition, Screen, ScreenSize},
+    status_report::StatusReport,
+    viewer::Viewer,
+};
